@@ -19,9 +19,9 @@ def list_solutions(user = False,from_date = None ) :
         solutions = [s for s in solutions if  datetime.strptime(s['CreatedAt'][:26],'%Y-%m-%dT%H:%M:%S.%f') > from_date ]
     return solutions
 
-def download_solution(file,solution_name,version) :
-    file = path.join('solutions',solution_name + '_' + version + '.zip')
-    logging.info(f'Download solution: {solution_name} to {file}')
+def download_solution(solution_name,version) :
+    logging.info(f'Download solution: {solution_name}-{version}')
+    file = path.join('solution',solution_name+'-'+version+'.zip')
     run(['vctl','solution','download',solution_name,version,'-f',file])
 
 def upload_solution(solution_file,user) :
@@ -29,14 +29,3 @@ def upload_solution(solution_file,user) :
     run(['vctl','solution','upload',solution_file,'-u',user])
 
 
-def import_solution_from_repo(solution_name,version) :
-    destination = '/files'
-    run(['vctl','vrep','user','import-solution',solution_name,version,destination,])
-
-def export_solution_to_repo(source,solution_name,version,description) :
-    if description :
-        cmd = ['vctl','vrep','user','export-solution',solution_name,version,source,'-s',description]
-    else :
-        cmd = ['vctl','vrep','user','export-solution',solution_name,version,source]
-    logging.info(f'Export vrep  \'{source}\'  to solution: {solution_name}-{version} ( ({" ".join(cmd)}))')
-    run(cmd)
\ No newline at end of file
